<?php

/**
 * @file
 * Enables modules and site configuration for a mop site installation.
 */

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Render\Markup;

/**
 * Implements hook_preprocess_template().
 */
function mop_preprocess_install_page(&$variables) {
  $variables['site_version'] = 'MOP_VERSION';
}

/**
 * Implements hook_install_tasks().
 */
function mop_install_tasks(&$install_state) {
  $tasks = [
    'mop_clear_cache' => [
      'display_name' => t('Clear cache'),
      'display' => TRUE,
      'type' => 'normal',
      'function' => 'mop_clear_cache',
    ],
  ];
  return $tasks;
}

/**
 * Implements hook_form_FORM_ID_alter() for install_configure_form().
 *
 * Allows the profile to alter the site configuration form.
 */
function mop_form_install_configure_form_alter(&$form, FormStateInterface $form_state) {
  $messenger = \Drupal::messenger();

  // Send message for install pdf.js library if it's not installed.
  $pdf_js_library = file_exists('libraries/pdf.js/build/pdf.js') && file_exists('libraries/pdf.js/build/pdf.worker.js');
  if (!$pdf_js_library) {
    $message = t('pdf.js library is not installed. Please install it from <a href="@library">here</a> and place in <em>libraries/</em> folder', ['@library' => 'http://mozilla.github.io/pdf.js/getting_started/']);
    $messenger->addWarning(Markup::create($message));
  }

}

/**
 * Implements mop_check_mop_updates().
 *
 * Check if new Opigno LMS release is available.
 *
 * Return TRUE or FALSE.
 *
 */
function mop_check_mop_updates() {
  // Get all available updates.
  $available = update_get_available();

  if (!isset($available['mop'])) {
    return FALSE;
  }

  $all_releases = array_keys($available['mop']['releases']);
  $last_release = $all_releases[0];
  $current_release = mop_get_current_mop_release();

  return $last_release !== $current_release;
}

/**
 * Implements mop_get_current_mop_release().
 *
 * Get current Opigno LMS release version.
 *
 * Return string with current release version or FALSE.
 *
 */
function mop_get_current_mop_release() {
  $profile = \Drupal::installProfile();
  if ($profile !== 'mop') {
    return FALSE;
  }

  $info = \Drupal::service('extension.list.module')->getExtensionInfo($profile);

  return $info['version'] ?? FALSE;
}

/**
 * Clear cache on installation.
 */
function mop_clear_cache() {
  drupal_flush_all_caches();
}

